/*
 * Copyright (C) 2003-2011 Karl Tauber <karl at jformdesigner dot com>
 * All Rights Reserved
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *  o Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 *  o Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 *  o Neither the name of JFormDesigner or Karl Tauber nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package com.jformdesigner.runtime;

import java.awt.*;
import java.lang.reflect.Method;
import com.jformdesigner.model.FormLayoutManager;

/**
 * @author Karl Tauber
 */
class FlowLayoutCreator
	extends AbstractLayoutCreator
{
	public LayoutManager createLayoutManager( Container container, FormLayoutManager formLayout )
		throws InstantiationException, IllegalAccessException
	{
		int align = formLayout.getPropertyInt( "alignment", FlowLayout.CENTER );
		int hgap = formLayout.getPropertyInt( "hgap", 5 );
		int vgap = formLayout.getPropertyInt( "vgap", 5 );
		boolean alignOnBaseline = formLayout.getPropertyBoolean( "alignOnBaseline" );

		FlowLayout layout = new FlowLayout( align, hgap, vgap );

		if( alignOnBaseline ) {
			// use reflection for Java 1.4 and Java 5 compatibility
			try {
				Method m = layout.getClass().getDeclaredMethod( "setAlignOnBaseline", new Class[] { Boolean.TYPE } );
				m.invoke( layout, new Object[] { Boolean.valueOf( alignOnBaseline ) } );
			} catch( Exception ex ) {
				// ignore when not running on Java 6 or later
			}
		}

		return layout;
	}
}
